pub struct AuthorityInfoAccessSyntax(pub Vec<AccessDescription>);Expand description
AuthorityInfoAccessSyntax as defined in RFC 5280 Section 4.2.2.1.
AuthorityInfoAccessSyntax ::= SEQUENCE SIZE (1..MAX) OF AccessDescriptionTuple Fields
0: Vec<AccessDescription>Trait Implementations
Sourceimpl<'a> AsMut<Vec<AccessDescription>> for AuthorityInfoAccessSyntax
impl<'a> AsMut<Vec<AccessDescription>> for AuthorityInfoAccessSyntax
Sourcefn as_mut(&mut self) -> &mut Vec<AccessDescription>
fn as_mut(&mut self) -> &mut Vec<AccessDescription>
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl<'a> AsRef<Vec<AccessDescription>> for AuthorityInfoAccessSyntax
impl<'a> AsRef<Vec<AccessDescription>> for AuthorityInfoAccessSyntax
Sourcefn as_ref(&self) -> &Vec<AccessDescription>
fn as_ref(&self) -> &Vec<AccessDescription>
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AssociatedOid for AuthorityInfoAccessSyntax
impl AssociatedOid for AuthorityInfoAccessSyntax
Sourceconst OID: ObjectIdentifier = ID_PE_AUTHORITY_INFO_ACCESS
const OID: ObjectIdentifier = ID_PE_AUTHORITY_INFO_ACCESS
The OID associated with this type.
Sourceimpl Clone for AuthorityInfoAccessSyntax
impl Clone for AuthorityInfoAccessSyntax
Sourceimpl Debug for AuthorityInfoAccessSyntax
impl Debug for AuthorityInfoAccessSyntax
Sourceimpl<'a> DecodeValue<'a> for AuthorityInfoAccessSyntax
impl<'a> DecodeValue<'a> for AuthorityInfoAccessSyntax
Sourceimpl Default for AuthorityInfoAccessSyntax
impl Default for AuthorityInfoAccessSyntax
Sourceimpl<'a> EncodeValue for AuthorityInfoAccessSyntax
impl<'a> EncodeValue for AuthorityInfoAccessSyntax
impl Eq for AuthorityInfoAccessSyntax
Sourceimpl<'a> FixedTag for AuthorityInfoAccessSyntax
impl<'a> FixedTag for AuthorityInfoAccessSyntax
Sourceimpl<'a> From<AuthorityInfoAccessSyntax> for Vec<AccessDescription>
impl<'a> From<AuthorityInfoAccessSyntax> for Vec<AccessDescription>
Sourcefn from(value: AuthorityInfoAccessSyntax) -> Self
fn from(value: AuthorityInfoAccessSyntax) -> Self
Converts to this type from the input type.
Sourceimpl<'a> From<Vec<AccessDescription>> for AuthorityInfoAccessSyntax
impl<'a> From<Vec<AccessDescription>> for AuthorityInfoAccessSyntax
Sourcefn from(value: Vec<AccessDescription>) -> Self
fn from(value: Vec<AccessDescription>) -> Self
Converts to this type from the input type.
impl StructuralPartialEq for AuthorityInfoAccessSyntax