pub struct PolicyMappings(pub Vec<PolicyMapping>);Expand description
PolicyMappings as defined in RFC 5280 Section 4.2.1.5.
PolicyMappings ::= SEQUENCE SIZE (1..MAX) OF SEQUENCE {Tuple Fields
0: Vec<PolicyMapping>Trait Implementations
Sourceimpl<'a> AsMut<Vec<PolicyMapping>> for PolicyMappings
impl<'a> AsMut<Vec<PolicyMapping>> for PolicyMappings
Sourcefn as_mut(&mut self) -> &mut Vec<PolicyMapping>
fn as_mut(&mut self) -> &mut Vec<PolicyMapping>
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl<'a> AsRef<Vec<PolicyMapping>> for PolicyMappings
impl<'a> AsRef<Vec<PolicyMapping>> for PolicyMappings
Sourcefn as_ref(&self) -> &Vec<PolicyMapping>
fn as_ref(&self) -> &Vec<PolicyMapping>
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AssociatedOid for PolicyMappings
impl AssociatedOid for PolicyMappings
Sourceconst OID: ObjectIdentifier = ID_CE_POLICY_MAPPINGS
const OID: ObjectIdentifier = ID_CE_POLICY_MAPPINGS
The OID associated with this type.
Sourceimpl Clone for PolicyMappings
impl Clone for PolicyMappings
Sourceimpl Criticality for PolicyMappings
impl Criticality for PolicyMappings
Sourceimpl Debug for PolicyMappings
impl Debug for PolicyMappings
Sourceimpl<'a> DecodeValue<'a> for PolicyMappings
impl<'a> DecodeValue<'a> for PolicyMappings
Sourceimpl<'a> EncodeValue for PolicyMappings
impl<'a> EncodeValue for PolicyMappings
impl Eq for PolicyMappings
Sourceimpl<'a> FixedTag for PolicyMappings
impl<'a> FixedTag for PolicyMappings
Sourceimpl<'a> From<PolicyMappings> for Vec<PolicyMapping>
impl<'a> From<PolicyMappings> for Vec<PolicyMapping>
Sourcefn from(value: PolicyMappings) -> Self
fn from(value: PolicyMappings) -> Self
Converts to this type from the input type.
Sourceimpl<'a> From<Vec<PolicyMapping>> for PolicyMappings
impl<'a> From<Vec<PolicyMapping>> for PolicyMappings
Sourcefn from(value: Vec<PolicyMapping>) -> Self
fn from(value: Vec<PolicyMapping>) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for PolicyMappings
impl PartialEq for PolicyMappings
impl StructuralPartialEq for PolicyMappings