pub struct SubjectAltName(pub GeneralNames);Expand description
SubjectAltName as defined in RFC 5280 Section 4.2.1.6.
SubjectAltName ::= GeneralNamesTuple Fields
0: GeneralNamesTrait Implementations
Sourceimpl<'a> AsMut<Vec<GeneralName>> for SubjectAltName
impl<'a> AsMut<Vec<GeneralName>> for SubjectAltName
Sourcefn as_mut(&mut self) -> &mut GeneralNames
fn as_mut(&mut self) -> &mut GeneralNames
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl<'a> AsRef<Vec<GeneralName>> for SubjectAltName
impl<'a> AsRef<Vec<GeneralName>> for SubjectAltName
Sourcefn as_ref(&self) -> &GeneralNames
fn as_ref(&self) -> &GeneralNames
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AssociatedOid for SubjectAltName
impl AssociatedOid for SubjectAltName
Sourceconst OID: ObjectIdentifier = ID_CE_SUBJECT_ALT_NAME
const OID: ObjectIdentifier = ID_CE_SUBJECT_ALT_NAME
The OID associated with this type.
Sourceimpl Clone for SubjectAltName
impl Clone for SubjectAltName
Sourceimpl Criticality for SubjectAltName
impl Criticality for SubjectAltName
Sourceimpl Debug for SubjectAltName
impl Debug for SubjectAltName
Sourceimpl<'a> DecodeValue<'a> for SubjectAltName
impl<'a> DecodeValue<'a> for SubjectAltName
Sourceimpl Default for SubjectAltName
impl Default for SubjectAltName
Sourceimpl<'a> EncodeValue for SubjectAltName
impl<'a> EncodeValue for SubjectAltName
impl Eq for SubjectAltName
Sourceimpl<'a> FixedTag for SubjectAltName
impl<'a> FixedTag for SubjectAltName
Sourceimpl<'a> From<SubjectAltName> for GeneralNames
impl<'a> From<SubjectAltName> for GeneralNames
Sourcefn from(value: SubjectAltName) -> Self
fn from(value: SubjectAltName) -> Self
Converts to this type from the input type.
Sourceimpl<'a> From<Vec<GeneralName>> for SubjectAltName
impl<'a> From<Vec<GeneralName>> for SubjectAltName
Sourcefn from(value: GeneralNames) -> Self
fn from(value: GeneralNames) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for SubjectAltName
impl PartialEq for SubjectAltName
impl StructuralPartialEq for SubjectAltName