pub struct SubjectInfoAccessSyntax(pub Vec<AccessDescription>);Expand description
SubjectInfoAccessSyntax as defined in RFC 5280 Section 4.2.2.2.
SubjectInfoAccessSyntax ::= SEQUENCE SIZE (1..MAX) OF AccessDescriptionTuple Fields
0: Vec<AccessDescription>Trait Implementations
Sourceimpl<'a> AsMut<Vec<AccessDescription>> for SubjectInfoAccessSyntax
impl<'a> AsMut<Vec<AccessDescription>> for SubjectInfoAccessSyntax
Sourcefn as_mut(&mut self) -> &mut Vec<AccessDescription>
fn as_mut(&mut self) -> &mut Vec<AccessDescription>
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl<'a> AsRef<Vec<AccessDescription>> for SubjectInfoAccessSyntax
impl<'a> AsRef<Vec<AccessDescription>> for SubjectInfoAccessSyntax
Sourcefn as_ref(&self) -> &Vec<AccessDescription>
fn as_ref(&self) -> &Vec<AccessDescription>
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AssociatedOid for SubjectInfoAccessSyntax
impl AssociatedOid for SubjectInfoAccessSyntax
Sourceconst OID: ObjectIdentifier = ID_PE_SUBJECT_INFO_ACCESS
const OID: ObjectIdentifier = ID_PE_SUBJECT_INFO_ACCESS
The OID associated with this type.
Sourceimpl Clone for SubjectInfoAccessSyntax
impl Clone for SubjectInfoAccessSyntax
Sourceimpl Debug for SubjectInfoAccessSyntax
impl Debug for SubjectInfoAccessSyntax
Sourceimpl<'a> DecodeValue<'a> for SubjectInfoAccessSyntax
impl<'a> DecodeValue<'a> for SubjectInfoAccessSyntax
Sourceimpl Default for SubjectInfoAccessSyntax
impl Default for SubjectInfoAccessSyntax
Sourceimpl<'a> EncodeValue for SubjectInfoAccessSyntax
impl<'a> EncodeValue for SubjectInfoAccessSyntax
impl Eq for SubjectInfoAccessSyntax
Sourceimpl<'a> FixedTag for SubjectInfoAccessSyntax
impl<'a> FixedTag for SubjectInfoAccessSyntax
Sourceimpl<'a> From<SubjectInfoAccessSyntax> for Vec<AccessDescription>
impl<'a> From<SubjectInfoAccessSyntax> for Vec<AccessDescription>
Sourcefn from(value: SubjectInfoAccessSyntax) -> Self
fn from(value: SubjectInfoAccessSyntax) -> Self
Converts to this type from the input type.
Sourceimpl<'a> From<Vec<AccessDescription>> for SubjectInfoAccessSyntax
impl<'a> From<Vec<AccessDescription>> for SubjectInfoAccessSyntax
Sourcefn from(value: Vec<AccessDescription>) -> Self
fn from(value: Vec<AccessDescription>) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for SubjectInfoAccessSyntax
impl PartialEq for SubjectInfoAccessSyntax
impl StructuralPartialEq for SubjectInfoAccessSyntax