pub struct SubjectKeyIdentifier(pub OctetString);Expand description
SubjectKeyIdentifier as defined in RFC 5280 Section 4.2.1.2.
SubjectKeyIdentifier ::= KeyIdentifierTuple Fields
0: OctetStringTrait Implementations
Sourceimpl<'a> AsMut<OctetString> for SubjectKeyIdentifier
impl<'a> AsMut<OctetString> for SubjectKeyIdentifier
Sourcefn as_mut(&mut self) -> &mut OctetString
fn as_mut(&mut self) -> &mut OctetString
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl<'a> AsRef<OctetString> for SubjectKeyIdentifier
impl<'a> AsRef<OctetString> for SubjectKeyIdentifier
Sourcefn as_ref(&self) -> &OctetString
fn as_ref(&self) -> &OctetString
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AssociatedOid for SubjectKeyIdentifier
impl AssociatedOid for SubjectKeyIdentifier
Sourceconst OID: ObjectIdentifier = ID_CE_SUBJECT_KEY_IDENTIFIER
const OID: ObjectIdentifier = ID_CE_SUBJECT_KEY_IDENTIFIER
The OID associated with this type.
Sourceimpl Clone for SubjectKeyIdentifier
impl Clone for SubjectKeyIdentifier
Sourceimpl Criticality for SubjectKeyIdentifier
impl Criticality for SubjectKeyIdentifier
Sourceimpl Debug for SubjectKeyIdentifier
impl Debug for SubjectKeyIdentifier
Sourceimpl<'a> DecodeValue<'a> for SubjectKeyIdentifier
impl<'a> DecodeValue<'a> for SubjectKeyIdentifier
Sourceimpl<'a> EncodeValue for SubjectKeyIdentifier
impl<'a> EncodeValue for SubjectKeyIdentifier
impl Eq for SubjectKeyIdentifier
Sourceimpl<'a> FixedTag for SubjectKeyIdentifier
impl<'a> FixedTag for SubjectKeyIdentifier
Sourceimpl<'a> From<OctetString> for SubjectKeyIdentifier
impl<'a> From<OctetString> for SubjectKeyIdentifier
Sourcefn from(value: OctetString) -> Self
fn from(value: OctetString) -> Self
Converts to this type from the input type.
Sourceimpl<'a> From<SubjectKeyIdentifier> for OctetString
impl<'a> From<SubjectKeyIdentifier> for OctetString
Sourcefn from(value: SubjectKeyIdentifier) -> Self
fn from(value: SubjectKeyIdentifier) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for SubjectKeyIdentifier
impl PartialEq for SubjectKeyIdentifier
impl StructuralPartialEq for SubjectKeyIdentifier
Sourceimpl<'a> TryFrom<SubjectPublicKeyInfo<AnyRef<'a>, BitStringRef<'a>>> for SubjectKeyIdentifier
impl<'a> TryFrom<SubjectPublicKeyInfo<AnyRef<'a>, BitStringRef<'a>>> for SubjectKeyIdentifier